"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createJsonWebToken = void 0;
const buffer_1 = require("buffer");
const encoding_1 = require("../utils/encoding");
/**
 *
 * Create a json web token according to {@link https://datatracker.ietf.org/doc/html/rfc7519 | RFC7519 }
 *
 */
const createJsonWebToken = (header, payload, signature) => {
    const encodedHeader = (0, encoding_1.base64ToBase64URL)(buffer_1.Buffer.from(JSON.stringify(header)).toString('base64'));
    const encodedPayload = (0, encoding_1.base64ToBase64URL)(buffer_1.Buffer.from(JSON.stringify(payload)).toString('base64'));
    const encodedSignature = (0, encoding_1.base64ToBase64URL)(buffer_1.Buffer.from(signature).toString('base64'));
    return `${encodedHeader}.${encodedPayload}.${encodedSignature}`;
};
exports.createJsonWebToken = createJsonWebToken;
//# sourceMappingURL=createJsonWebToken.js.map