"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createJwtSignableInput = void 0;
const buffer_1 = require("buffer");
const encoding_1 = require("../utils/encoding");
/**
 *
 * Converts a JSON header and payload into a byte array which can be used to verify and sign a JWT
 *
 */
const createJwtSignableInput = (header, payload) => {
    if (Object.keys(header).length === 0) {
        throw new Error('Can not create JWT with an empty header');
    }
    if (Object.keys(payload).length === 0) {
        throw new Error('Can not create JWT with an empty payload');
    }
    const encodedHeader = (0, encoding_1.base64ToBase64URL)(buffer_1.Buffer.from(JSON.stringify(header)).toString('base64'));
    const encodedPayload = (0, encoding_1.base64ToBase64URL)(buffer_1.Buffer.from(JSON.stringify(payload)).toString('base64'));
    const toBeSignedString = `${encodedHeader}.${encodedPayload}`;
    return new Uint8Array(buffer_1.Buffer.from(toBeSignedString));
};
exports.createJwtSignableInput = createJwtSignableInput;
//# sourceMappingURL=createJsonWebTokenSignableInput.js.map