import { z } from 'zod';
/**
 *
 * {@link https://openid.net/specs/openid-federation-1_0.html#section-5.1.3-1 | openID Provider}
 *
 */
export declare const openIdProviderEntityMetadata: {
    identifier: "openid_provider";
    schema: z.ZodObject<z.objectUtil.extendShape<{
        signed_jwks_uri: z.ZodOptional<z.ZodString>;
        jwks_uri: z.ZodOptional<z.ZodString>;
        jwks: z.ZodOptional<z.ZodObject<{
            keys: z.ZodArray<z.ZodObject<{
                kty: z.ZodString;
                kid: z.ZodString;
                use: z.ZodOptional<z.ZodString>;
                key_ops: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                alg: z.ZodOptional<z.ZodString>;
                x5u: z.ZodOptional<z.ZodString>;
                x5c: z.ZodOptional<z.ZodString>;
                x5t: z.ZodOptional<z.ZodString>;
                'x5t#S256': z.ZodOptional<z.ZodString>;
            }, "passthrough", z.ZodTypeAny, z.objectOutputType<{
                kty: z.ZodString;
                kid: z.ZodString;
                use: z.ZodOptional<z.ZodString>;
                key_ops: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                alg: z.ZodOptional<z.ZodString>;
                x5u: z.ZodOptional<z.ZodString>;
                x5c: z.ZodOptional<z.ZodString>;
                x5t: z.ZodOptional<z.ZodString>;
                'x5t#S256': z.ZodOptional<z.ZodString>;
            }, z.ZodTypeAny, "passthrough">, z.objectInputType<{
                kty: z.ZodString;
                kid: z.ZodString;
                use: z.ZodOptional<z.ZodString>;
                key_ops: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                alg: z.ZodOptional<z.ZodString>;
                x5u: z.ZodOptional<z.ZodString>;
                x5c: z.ZodOptional<z.ZodString>;
                x5t: z.ZodOptional<z.ZodString>;
                'x5t#S256': z.ZodOptional<z.ZodString>;
            }, z.ZodTypeAny, "passthrough">>, "many">;
        }, "strip", z.ZodTypeAny, {
            keys: z.objectOutputType<{
                kty: z.ZodString;
                kid: z.ZodString;
                use: z.ZodOptional<z.ZodString>;
                key_ops: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                alg: z.ZodOptional<z.ZodString>;
                x5u: z.ZodOptional<z.ZodString>;
                x5c: z.ZodOptional<z.ZodString>;
                x5t: z.ZodOptional<z.ZodString>;
                'x5t#S256': z.ZodOptional<z.ZodString>;
            }, z.ZodTypeAny, "passthrough">[];
        }, {
            keys: z.objectInputType<{
                kty: z.ZodString;
                kid: z.ZodString;
                use: z.ZodOptional<z.ZodString>;
                key_ops: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                alg: z.ZodOptional<z.ZodString>;
                x5u: z.ZodOptional<z.ZodString>;
                x5c: z.ZodOptional<z.ZodString>;
                x5t: z.ZodOptional<z.ZodString>;
                'x5t#S256': z.ZodOptional<z.ZodString>;
            }, z.ZodTypeAny, "passthrough">[];
        }>>;
        organization_name: z.ZodOptional<z.ZodString>;
        contacts: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        logo_uri: z.ZodOptional<z.ZodString>;
        policy_uri: z.ZodOptional<z.ZodString>;
        homepage_uri: z.ZodOptional<z.ZodString>;
    }, {
        client_registration_types_supported: z.ZodArray<z.ZodUnion<[z.ZodLiteral<"automatic">, z.ZodLiteral<"explicit">]>, "many">;
        federation_registration_endpoint: z.ZodOptional<z.ZodString>;
        request_authentication_methods_supported: z.ZodOptional<z.ZodObject<{
            authorization_endpoint: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            pushed_authorization_request_endpoint: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        }, "strip", z.ZodTypeAny, {
            authorization_endpoint?: string[] | undefined;
            pushed_authorization_request_endpoint?: string[] | undefined;
        }, {
            authorization_endpoint?: string[] | undefined;
            pushed_authorization_request_endpoint?: string[] | undefined;
        }>>;
        request_authentication_signing_alg_values_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    }>, "strip", z.ZodTypeAny, {
        client_registration_types_supported: ("automatic" | "explicit")[];
        jwks?: {
            keys: z.objectOutputType<{
                kty: z.ZodString;
                kid: z.ZodString;
                use: z.ZodOptional<z.ZodString>;
                key_ops: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                alg: z.ZodOptional<z.ZodString>;
                x5u: z.ZodOptional<z.ZodString>;
                x5c: z.ZodOptional<z.ZodString>;
                x5t: z.ZodOptional<z.ZodString>;
                'x5t#S256': z.ZodOptional<z.ZodString>;
            }, z.ZodTypeAny, "passthrough">[];
        } | undefined;
        signed_jwks_uri?: string | undefined;
        jwks_uri?: string | undefined;
        organization_name?: string | undefined;
        contacts?: string[] | undefined;
        logo_uri?: string | undefined;
        policy_uri?: string | undefined;
        homepage_uri?: string | undefined;
        federation_registration_endpoint?: string | undefined;
        request_authentication_methods_supported?: {
            authorization_endpoint?: string[] | undefined;
            pushed_authorization_request_endpoint?: string[] | undefined;
        } | undefined;
        request_authentication_signing_alg_values_supported?: string[] | undefined;
    }, {
        client_registration_types_supported: ("automatic" | "explicit")[];
        jwks?: {
            keys: z.objectInputType<{
                kty: z.ZodString;
                kid: z.ZodString;
                use: z.ZodOptional<z.ZodString>;
                key_ops: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                alg: z.ZodOptional<z.ZodString>;
                x5u: z.ZodOptional<z.ZodString>;
                x5c: z.ZodOptional<z.ZodString>;
                x5t: z.ZodOptional<z.ZodString>;
                'x5t#S256': z.ZodOptional<z.ZodString>;
            }, z.ZodTypeAny, "passthrough">[];
        } | undefined;
        signed_jwks_uri?: string | undefined;
        jwks_uri?: string | undefined;
        organization_name?: string | undefined;
        contacts?: string[] | undefined;
        logo_uri?: string | undefined;
        policy_uri?: string | undefined;
        homepage_uri?: string | undefined;
        federation_registration_endpoint?: string | undefined;
        request_authentication_methods_supported?: {
            authorization_endpoint?: string[] | undefined;
            pushed_authorization_request_endpoint?: string[] | undefined;
        } | undefined;
        request_authentication_signing_alg_values_supported?: string[] | undefined;
    }>;
    policySchema: z.ZodObject<Record<string, z.ZodType<any, z.ZodTypeDef, any>>, z.UnknownKeysParam, z.ZodTypeAny, {
        [x: string]: any;
    }, {
        [x: string]: any;
    }>;
};
export type OpenIdProviderMetadata = z.input<(typeof openIdProviderEntityMetadata)['schema']>;
