import { type fetchEntityConfiguration } from '../entityConfiguration';
import { fetchEntityStatementChain } from '../entityStatement';
import type { VerifyCallback } from '../utils';
type Options = {
    verifyJwtCallback: VerifyCallback;
    entityId: string;
    trustAnchorEntityIds: Array<string>;
};
type TrustChain = {
    chain: Awaited<ReturnType<typeof fetchEntityStatementChain>>;
    leafEntityConfiguration: Awaited<ReturnType<typeof fetchEntityConfiguration>>;
    trustAnchorEntityConfiguration: Awaited<ReturnType<typeof fetchEntityConfiguration>>;
};
/**
 * Resolves the trust chains for the given entityId and trust anchor entityIds.
 *
 * @param options - The options for the trust chain resolution.
 * @returns A promise that resolves to an array of trust chains. (The first item in the trust chain is the leaf entity configuration, the last item is the trust anchor entity configuration)
 */
export declare const resolveTrustChains: (options: Options) => Promise<Array<TrustChain>>;
export {};
